@@ -22,7 +22,8 @@ __PACKAGE__->mk_ro_accessors(qw/
                                 components
                                 resultset_components
                                 relationships
-                                inflect_map
+                                inflect_singular
+                                inflect_plural
                                 moniker_map
                                 db_schema
                                 debug
@@ -98,16 +99,21 @@ a scalar moniker.  If the hash entry does not exist, or the function
 returns a false/undef value, the code falls back to default behavior
 for that table name.
 
+=head2 inflect_plural
+
+Just like L</moniker_map> above, but for pluralizing relationship names.
+
+=head2 inflect_singular
+
+Just like L</moniker_map> above, but for singularizing relationship names.
+
 =head2 inflect_map
 
-Just like L</moniker_map> above, but for inflecting (pluralizing)
-relationship names.
+Deprecated.  Equivalent to L</inflect_plural>.
 
 =head2 inflect
 
-Deprecated.  Equivalent to L</inflect_map>, but previously only took
-a hashref argument, not a coderef.  If you set C<inflect> to anything,
-that setting will be copied to L</inflect_map>.
+Deprecated.  Equivalent to L</inflect_plural>.
 
 =head2 connect_info
 
@@ -163,7 +169,6 @@ sub new {
     bless $self => $class;
 
     $self->{db_schema}  ||= '';
-    $self->{constraint} ||= qr//;
     $self->_ensure_arrayref(qw/additional_classes
                                additional_base_classes
                                left_base_classes
@@ -177,8 +182,12 @@ sub new {
     $self->{monikers} = {};
     $self->{classes} = {};
 
-    # Support deprecated argument name
-    $self->{inflect_map} ||= $self->{inflect};
+    # Support deprecated arguments
+    for(qw/inflect_map inflect/) {
+        warn "Argument $_ is deprecated in favor of 'inflect_plural'"
+            if $self->{$_};
+    }
+    $self->{inflect_plural} ||= $self->{inflect_map} || $self->{inflect};
 
     $self;
 }
@@ -252,9 +261,17 @@ sub _load_classes {
 
     my $constraint = $self->constraint;
     my $exclude = $self->exclude;
-    my @tables = sort grep
-        { /$constraint/ && (!$exclude || ! /$exclude/) }
-            $self->_tables_list;
+    my @tables = sort $self->_tables_list;
+
+    warn "No tables found in database, nothing to load" if !@tables;
+
+    if(@tables) {
+        @tables = grep { /$constraint/ } @tables if $constraint;
+        @tables = grep { ! /$exclude/ } @tables if $exclude;
+
+        warn "All tables excluded by constraint/exclude, nothing to load"
+            if !@tables;
+    }
 
     $self->{_tables} = \@tables;
 
@@ -372,7 +389,8 @@ sub _load_relationships {
 
     # Let RelBuilder take over from here
     my $relbuilder = DBIx::Class::Schema::Loader::RelBuilder->new(
-        $self->schema, \%fk_info, $self->inflect_map
+        $self->schema, \%fk_info, $self->inflect_plural,
+        $self->inflect_singular
     );
     $relbuilder->setup_rels($self->debug);
 }
