@@ -43,7 +43,7 @@ sub _monikerize {
 sub run_tests {
     my $self = shift;
 
-    plan tests => 60;
+    plan tests => 73;
 
     $self->create();
 
@@ -59,13 +59,20 @@ sub run_tests {
         additional_base_classes => 'TestAdditionalBase',
         left_base_classes       => [ qw/TestLeftBase/ ],
         components              => [ qw/TestComponent/ ],
-        resultset_components    => [ qw/TestRSComponent/ ],
-        inflect_map             => { loader_test4 => 'loader_test4zes' },
+        inflect_plural          => { loader_test4 => 'loader_test4zes' },
+        inflect_singular        => { fkid => 'fkid_singular' },
         moniker_map             => \&_monikerize,
         debug                   => $debug,
     );
 
     $loader_opts{db_schema} = $self->{db_schema} if $self->{db_schema};
+    eval { require Class::Inspector };
+    if($@) {
+        $self->{_no_rs_components} = 1;
+    }
+    else {
+        $loader_opts{resultset_components} = [ qw/TestRSComponent/ ];
+    }
 
     {
        my @loader_warnings;
@@ -143,7 +150,6 @@ sub run_tests {
         can_ok( $class1, 'test_additional_base_override' ) or $skip_tabo = 1;
         can_ok( $class1, 'test_additional_base_additional' ) or $skip_taba = 1;
         can_ok( $class1, 'dbix_class_testcomponent' ) or $skip_tcomp = 1;
-        can_ok( $rsobj1, 'dbix_class_testrscomponent' ) or $skip_trscomp = 1;
         can_ok( $class1, 'loader_test1_classmeth' ) or $skip_cmeth = 1;
 
         TODO: {
@@ -177,9 +183,14 @@ sub run_tests {
         }
 
         SKIP: {
-            skip "Pre-requisite test failed", 1 if $skip_trscomp;
-            is( $rsobj1->dbix_class_testrscomponent,
-                'dbix_class_testrscomponent works' );
+            skip "These two tests need Class::Inspector installed", 2
+                     if $self->{_no_rs_components};
+            can_ok($rsobj1, 'dbix_class_testrscomponent') or $skip_trscomp = 1;
+            SKIP: {
+                skip "Pre-requisite test failed", 1 if $skip_trscomp;
+                is( $rsobj1->dbix_class_testrscomponent,
+                    'dbix_class_testrscomponent works' );
+            }
         }
 
         SKIP: {
@@ -245,6 +256,34 @@ sub run_tests {
         my $class9   = $classes->{loader_test9};
         my $rsobj9   = $conn->resultset($moniker9);
 
+        my $moniker16 = $monikers->{loader_test16};
+        my $class16   = $classes->{loader_test16};
+        my $rsobj16   = $conn->resultset($moniker16);
+
+        my $moniker17 = $monikers->{loader_test17};
+        my $class17   = $classes->{loader_test17};
+        my $rsobj17   = $conn->resultset($moniker17);
+
+        my $moniker18 = $monikers->{loader_test18};
+        my $class18   = $classes->{loader_test18};
+        my $rsobj18   = $conn->resultset($moniker18);
+
+        my $moniker19 = $monikers->{loader_test19};
+        my $class19   = $classes->{loader_test19};
+        my $rsobj19   = $conn->resultset($moniker19);
+
+        my $moniker20 = $monikers->{loader_test20};
+        my $class20   = $classes->{loader_test20};
+        my $rsobj20   = $conn->resultset($moniker20);
+
+        my $moniker21 = $monikers->{loader_test21};
+        my $class21   = $classes->{loader_test21};
+        my $rsobj21   = $conn->resultset($moniker21);
+
+        my $moniker22 = $monikers->{loader_test22};
+        my $class22   = $classes->{loader_test22};
+        my $rsobj22   = $conn->resultset($moniker22);
+
         isa_ok( $rsobj3, "DBIx::Class::ResultSet" );
         isa_ok( $rsobj4, "DBIx::Class::ResultSet" );
         isa_ok( $rsobj5, "DBIx::Class::ResultSet" );
@@ -252,10 +291,17 @@ sub run_tests {
         isa_ok( $rsobj7, "DBIx::Class::ResultSet" );
         isa_ok( $rsobj8, "DBIx::Class::ResultSet" );
         isa_ok( $rsobj9, "DBIx::Class::ResultSet" );
+        isa_ok( $rsobj16, "DBIx::Class::ResultSet" );
+        isa_ok( $rsobj17, "DBIx::Class::ResultSet" );
+        isa_ok( $rsobj18, "DBIx::Class::ResultSet" );
+        isa_ok( $rsobj19, "DBIx::Class::ResultSet" );
+        isa_ok( $rsobj20, "DBIx::Class::ResultSet" );
+        isa_ok( $rsobj21, "DBIx::Class::ResultSet" );
+        isa_ok( $rsobj22, "DBIx::Class::ResultSet" );
 
         # basic rel test
         my $obj4 = $rsobj4->find(123);
-        isa_ok( $obj4->fkid, $class3);
+        isa_ok( $obj4->fkid_singular, $class3);
 
         my $obj3 = $rsobj3->find(1);
         my $rs_rel4 = $obj3->search_related('loader_test4zes');
@@ -274,6 +320,26 @@ sub run_tests {
         my $obj8 = $rsobj8->find(1);
         isa_ok( $obj8->loader_test7, $class7);
 
+        # test double-fk 17 ->-> 16
+        my $obj17 = $rsobj17->find(33);
+
+        my $rs_rel16_one = $obj17->loader16_one;
+        isa_ok($rs_rel16_one, $class16);
+        is($rs_rel16_one->dat, 'y16');
+
+        my $rs_rel16_two = $obj17->loader16_two;
+        isa_ok($rs_rel16_two, $class16);
+        is($rs_rel16_two->dat, 'z16');
+
+        my $obj16 = $rsobj16->find(2);
+        my $rs_rel17 = $obj16->search_related('loader_test17_loader16_ones');
+        isa_ok($rs_rel17->first, $class17);
+        is($rs_rel17->first->id, 3);
+        
+        # XXX test m:m 18 <- 20 -> 19
+        
+        # XXX test double-fk m:m 21 <- 22 -> 21
+
         # from Chisel's tests...
         SKIP: {
             if($self->{vendor} =~ /sqlite/i) {
